@@ -1,6 +1,6 @@
 import os
 
-from pyzo.util.qt import QtCore, QtGui, QtWidgets
+from pyzo.qt import QtCore, QtGui, QtWidgets
 
 import pyzo
 from pyzo.util import zon as ssdf
@@ -182,9 +182,8 @@ class StyleEdit(QtWidgets.QWidget):
         """
 
         checkBox = QtWidgets.QCheckBox()
-
         self.setters[key] = lambda val, check=checkBox: check.setCheckState(
-            val == "yes"
+            [QtCore.Qt.CheckState.Unchecked, QtCore.Qt.CheckState.Checked][val == "yes"]
         )
 
         checkBox.stateChanged.connect(
@@ -437,6 +436,7 @@ class ThemeEditorWidget(QtWidgets.QWidget):
 
         if prev != new:
             pyzo.config.settings.theme = new
+            pyzo.saveConfig()
             # This may be better
             pyzo.main.restart()
         else:
