@@ -118,7 +118,6 @@ class PyzoInterpreter:
       * introspector: the introspector instance (a subclassed yoton.RepChannel)
       * magician: the object that handles the magic commands
       * guiApp: a wrapper for the integrated GUI application
-      * sleeptime: the amount of time (in seconds) to sleep at each iteration
 
     """
 
@@ -159,10 +158,6 @@ class PyzoInterpreter:
         # Init buffer to deal with multi-line command in the shell
         self._buffer = []
 
-        # Init sleep time. 0.001 result in 0% CPU usage at my laptop (Windows),
-        # but 8% CPU usage at my older laptop (on Linux).
-        self.sleeptime = 0.01  # 100 Hz
-
         # Create compiler
         if sys.platform.startswith("java"):
             import compiler
@@ -221,7 +216,7 @@ class PyzoInterpreter:
 
         # Enter main
         try:
-            self.guiApp.run(self.process_commands, self.sleeptime)
+            self.guiApp.run(self.process_commands)
         except SystemExit:
             # Set self._exitException if it is not set yet
             type, value, tb = sys.exc_info()
@@ -488,7 +483,7 @@ class PyzoInterpreter:
         event loop).
         """
 
-        self.guiApp = guiintegration.App_base()
+        self.guiApp = guiintegration.App_nogui()
         self.guiName = guiName = startup_info["gui"].upper()
         guiError = ""
 
@@ -504,7 +499,7 @@ class PyzoInterpreter:
                     ("PYSIDE", guiintegration.App_pyside),
                     ("PYQT4", guiintegration.App_pyqt4),
                     # ('WX', guiintegration.App_wx),
-                    ("ASYNCIO", guiintegration.App_asyncio),
+                    ("ASYNCIO", guiintegration.App_asyncio_new),
                     ("TK", guiintegration.App_tk),
                 ]:
                     try:
@@ -516,7 +511,7 @@ class PyzoInterpreter:
                 else:
                     guiName = ""
             elif guiName == "ASYNCIO":
-                self.guiApp = guiintegration.App_asyncio()
+                self.guiApp = guiintegration.App_asyncio_new()
             elif guiName == "TK":
                 self.guiApp = guiintegration.App_tk()
             elif guiName == "WX":
@@ -597,11 +592,15 @@ class PyzoInterpreter:
             # IPython wraps std streams just like we do below, but
             # pyreadline adds *another* wrapper, which is where it
             # goes wrong. Here we set it back to bypass pyreadline.
-            from IPython.utils import io
 
-            io.stdin = io.IOStream(sys.stdin)
-            io.stdout = io.IOStream(sys.stdout)
-            io.stderr = io.IOStream(sys.stderr)
+            if IPython.version_info < (
+                8,
+            ):  # corrects a problem with IOStream from IPython 8.x.x
+                from IPython.utils import io
+
+                io.stdin = io.IOStream(sys.stdin)
+                io.stdout = io.IOStream(sys.stdout)
+                io.stderr = io.IOStream(sys.stderr)
 
             # Ipython uses msvcrt e.g. for pausing between pages
             # but this does not work in pyzo
