@@ -16,7 +16,7 @@ from .. import paths
 
 
 def get_interpreters(minimumVersion=None):
-    """ get_interpreters(minimumVersion=None)
+    """get_interpreters(minimumVersion=None)
     Returns a list of PythonInterpreter instances.
     If minimumVersion is given, return only the interprers with at least that
     version, and also sort the result by version number.
@@ -48,7 +48,7 @@ def get_interpreters(minimumVersion=None):
 
 
 def _select_interpreters(interpreters, minimumVersion):
-    """ Given a list of PythonInterpreter instances, return a list with
+    """Given a list of PythonInterpreter instances, return a list with
     the interpreters selected that are valid and have their version equal
     or larger than the given minimimVersion. The returned list is sorted
     by version number.
@@ -112,6 +112,15 @@ def _get_interpreters_win():
 def _get_interpreters_posix():
     found = []
 
+    def isPathValidPythonExe(filename):
+        fname = os.path.split(filename)[1]
+        return (
+            fname.startswith(("python", "pypy"))
+            and not fname.count("config")
+            and len(fname) < 16
+            and os.path.isfile(filename)
+        )
+
     # Look for system Python interpreters
     for searchpath in ["/usr/bin", "/usr/local/bin", "/opt/local/bin"]:
         searchpath = os.path.expanduser(searchpath)
@@ -124,14 +133,12 @@ def _get_interpreters_posix():
 
         # Search for python executables
         for fname in files:
-            if fname.startswith(("python", "pypy")) and not fname.count("config"):
-                if len(fname) < 16:
-                    # Get filename and resolve symlink
-                    filename = os.path.join(searchpath, fname)
-                    filename = os.path.realpath(filename)
-                    # Seen on OS X that was not a valid file
-                    if os.path.isfile(filename):
-                        found.append(filename)
+            # Get filename and resolve symlink
+            # Seen on OS X that was not a valid file
+            filename = os.path.join(searchpath, fname)
+            filename = os.path.realpath(filename)
+            if isPathValidPythonExe(filename):
+                found.append(filename)
 
     # Look for user-installed Python interpreters such as pypy and anaconda
     for rootname in ["~", "/usr/local"]:
@@ -145,6 +152,13 @@ def _get_interpreters_posix():
                     if os.path.isfile(exename):
                         found.append(exename)
 
+    # Look for Python interpreter provided by PYZO_DEFAULT_SHELL_PYTHON_EXE env-var
+    if "PYZO_DEFAULT_SHELL_PYTHON_EXE" in os.environ:
+        filename = os.environ["PYZO_DEFAULT_SHELL_PYTHON_EXE"]
+        filename = os.path.realpath(filename)
+        if isPathValidPythonExe(filename):
+            found.append(filename)
+
     # Remove pythonw, pythonm and the like
     found = set(found)
     for path in list(found):
@@ -156,8 +170,7 @@ def _get_interpreters_posix():
 
 
 def _get_interpreters_pyzo():
-    """ Get a list of known Pyzo interpreters.
-    """
+    """Get a list of known Pyzo interpreters."""
     pythonname = "python" + ".exe" * sys.platform.startswith("win")
     exes = []
     for d in paths.pyzo_dirs():
@@ -172,8 +185,7 @@ def _get_interpreters_pyzo():
 
 
 def _get_interpreters_conda():
-    """ Get known conda environments
-    """
+    """Get known conda environments"""
     if sys.platform.startswith("win"):
         pythonname = "python" + ".exe"
     else:
@@ -191,8 +203,7 @@ def _get_interpreters_conda():
 
 
 def _get_interpreters_pipenv():
-    """ Get known pipenv environments
-    """
+    """Get known pipenv environments"""
     if sys.platform.startswith("win"):
         pythonname = "Scripts\\python" + ".exe"
     else:
@@ -209,7 +220,7 @@ def _get_interpreters_pipenv():
 
 
 def _get_interpreters_relative():
-    """ Get interpreters relative to our prefix and the parent directory.
+    """Get interpreters relative to our prefix and the parent directory.
     This allows Pyzo to be shipped inside a pre-installed conda env.
     """
     pythonname = "python" + ".exe" * sys.platform.startswith("win")
